# kanga

MCMC diagnostics in Python.

kanga can be installed via conda or via pip.

To install kanga using conda, run
```
conda install -c conda-forge kanga
```

To install kanga using pip, run
```
pip install kanga
```
